
# Slot: date


Date that a namespace was last modified or released

URI: [nwb_schema_language:date](https://w3id.org/p2p_ld/nwb-schema-language/date)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Datetime](types/Datetime.md)

## Parents


## Children


## Used by

 * [Namespace](Namespace.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:dateModified |
| **Examples:** | | Example(value='2017-04-25 17:14:13', description=None, object=None) |

